@@ -1,12 +1,11 @@
+from .exceptions import DatasetNotFoundException
+import torch.utils.data as data
+import torch
+import numpy as np
 import json
 import os
 import random
-import cv2
-import numpy as np
-import torch
-import torch.utils.data as data
-from .exceptions import DatasetNotFoundException
-from ...transforms import empty_transform
+from PIL import Image
 
 
 def __maxidx__(_list):
@@ -34,7 +33,7 @@ class Dataset(data.Dataset):
         """
 
         self.init_label_types(label_types)
-        self.init_transform(transform)
+        self.transform = transform
         self.load_data(root, train)
         self.load_label(root)
         self.__totorch__()
@@ -77,14 +76,15 @@ class Dataset(data.Dataset):
         for key in self.ys.keys():
             self.ys[key] = torch.from_numpy(np.array(self.ys[key]))
 
-    def __cvimg__(self, path, convert2rgb=True):
-        """
-            read image in RGB mode.
-        """
-        img_cv = cv2.imread(path)
-        if convert2rgb:
-            img_cv = cv2.cvtColor(img_cv, cv2.COLOR_BGR2RGB)
-        return img_cv
+    # def __cvimg__(self, path, convert2rgb=True):
+    #     """
+    #         deprecated method (because of thread lock issue:https://zhuanlan.zhihu.com/p/133707658)
+    #         read image in RGB mode.
+    #     """
+    #     img_cv = cv2.imread(path)
+    #     if convert2rgb:
+    #         img_cv = cv2.cvtColor(img_cv, cv2.COLOR_BGR2RGB)
+    #     return img_cv
 
     def __getitem__(self, index):
         """
@@ -94,8 +94,11 @@ class Dataset(data.Dataset):
             Args:
                 index:
         """
-        img = self.__cvimg__(self.data[index])
-        img = self.transform(img)
+        # img = self.__cvimg__(self.data[index])
+        img = Image.open(self.data[index])
+        img = img.convert('RGB')
+        if self.transform:
+            img = self.transform(img)
         target = [self.ys[k][index] for k in self.ys.keys()]
         if len(target) == 1:
             target = target[0]
@@ -114,11 +117,6 @@ class Dataset(data.Dataset):
             assert x in self.dataset_labels
         self.ys = {x: [] for x in label_types}
 
-    def init_transform(self, transform):
-        if transform is None:
-            transform = empty_transform
-        self.transform = transform
-
     def load_data(self, root, train):
         """
             pre-load image path,
@@ -151,4 +149,5 @@ class Dataset(data.Dataset):
             if 'single' in self.ys.keys():
                 self.ys['single'].append(__maxidx__(y))
             if 'distribution' in self.ys.keys():
-                self.ys['distribution'].append(y)
+                target = np.array(y)/sum(y)
+                self.ys['distribution'].append(target.astype(np.float32))
